"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInterpolationKeys = getInterpolationKeys;
exports.parseInterpolationStrings = parseInterpolationStrings;
exports.getInterpolatedStringFactory = getInterpolatedStringFactory;
exports.getInterpolatedHeadersFactory = getInterpolatedHeadersFactory;
const index_js_1 = require("./index.js");
function getInterpolationKeys(...interpolationStrings) {
    return interpolationStrings.reduce((keys, str) => [
        ...keys,
        ...(str ? index_js_1.stringInterpolator.parseRules(str).map((match) => match.key) : []),
    ], []);
}
function parseInterpolationStrings(interpolationStrings, argTypeMap) {
    const interpolationKeys = getInterpolationKeys(...interpolationStrings);
    const args = {};
    const contextVariables = {};
    for (const interpolationKey of interpolationKeys) {
        const interpolationKeyParts = interpolationKey.split('.');
        const varName = interpolationKeyParts[interpolationKeyParts.length - 1];
        const initialObject = interpolationKeyParts[0];
        const argType = argTypeMap && varName in argTypeMap
            ? argTypeMap[varName]
            : interpolationKeyParts.length > 2
                ? 'JSON'
                : 'ID';
        switch (initialObject) {
            case 'args':
                args[varName] = {
                    type: argType,
                };
                break;
            case 'context':
                contextVariables[varName] = `Scalars['${argType}']`;
                break;
        }
    }
    return {
        args,
        contextVariables,
    };
}
function getInterpolatedStringFactory(nonInterpolatedString) {
    return resolverData => index_js_1.stringInterpolator.parse(nonInterpolatedString, resolverData);
}
function getInterpolatedHeadersFactory(nonInterpolatedHeaders = {}) {
    return resolverData => {
        const headers = {};
        for (const headerName in nonInterpolatedHeaders) {
            const headerValue = nonInterpolatedHeaders[headerName];
            if (headerValue) {
                const interpolatedValue = index_js_1.stringInterpolator.parse(headerValue, resolverData);
                if (interpolatedValue) {
                    headers[headerName] = interpolatedValue;
                }
            }
        }
        return headers;
    };
}
